@@ -54,15 +54,23 @@ class GooBook():
         self.cache = Cache(config)
         self.cache.load()
 
-    def query(self, query):
-        """Do the query, and print it out in"""
+    def query(self, query, simple=False):
+        """Do the query, and print it out in
+
+        simple=False is the mutt format
+        simple format is:
+          "Name <email>"
+        simple format for group matches is a , separated list of Name <email>
+        the group name is not printed using simple format.
+        """
         # query contacts
         matching_contacts = sorted(self.__query_contacts(query), key=lambda c: c.display_name)
         # query groups
         matching_groups = sorted(self.__query_groups(query), key=lambda g: g[0])
-        # mutt's query_command expects the first line to be a message,
-        # which it discards.
-        print('')
+        if not simple:
+            # mutt's query_command expects the first line to be a message,
+            # which it discards.
+            print('')
         for contact in matching_contacts:
             if contact.emails:
                 emailaddrs = sorted(contact.emails)
@@ -73,13 +81,20 @@ class GooBook():
                     extra_str = kind
                     if groups_str:
                         extra_str = extra_str + ' groups: ' + groups_str
-                    print('\t'.join((emailaddr, contact.display_name, extra_str)))
+                    if simple:
+                        print(f"{contact.display_name} <{emailaddr}>")
+                    else:
+                        print('\t'.join((emailaddr, contact.display_name, extra_str)))
+
         for title, contacts in matching_groups:
             emails = ['%s <%s>' % (c.display_name, c.emails[0][0]) for c in contacts if c.emails]
             emails = ', '.join(emails)
             if not emails:
                 continue
-            print('%s\t%s (group)' % (emails, title))
+            if simple:
+                print(emails)
+            else:
+                print('%s\t%s (group)' % (emails, title))
 
     def query_details(self, query):
         """Method for querying the contacts and printing a detailed view."""
@@ -126,10 +141,9 @@ class GooBook():
                     lines = address.splitlines()
                     lines[0] = '%s ( %s )' % (lines[0], kind)
                     print("\t" + '\n\t'.join(lines), file=out)
-            if contact.groups:
+            groups = set(contact.groups).difference(('My Contacts',))
+            if groups:
                 print("Groups:", file=out)
-                groups = set(contact.groups)
-                groups = groups.difference(('My Contacts',))
                 groups_str = '\n\t'.join(groups)
                 print("\t" + groups_str, file=out)
 
@@ -265,12 +279,15 @@ class Cache():
 
 
 def parse_contact(person, groupname_by_id):
-    """Extracts interesting contact info from cache."""
+    """Extracts interesting contact info from cache.
+
+    https://developers.google.com/people/api/rest/v1/people
+    """
     contact = Storage()
     contact.emails = []
     contact.birthday = None  # datetime.date
-    contact.im = []  # TODO
-    contact.addresses = []  # TODO
+    contact.im = []
+    contact.addresses = []
     contact.display_name = None
     contact.all_names = []
     contact.groups = []
@@ -280,7 +297,7 @@ def parse_contact(person, groupname_by_id):
     for emaila in person.get('emailAddresses', []):
         contact.emails.append(TypedValue(emaila['value'], emaila.get('type', '')))
 
-    if 'birthdays' in person.keys() and person['birthdays']:
+    if 'birthdays' in person.keys() and person['birthdays'] and 'date' in person['birthdays'][0]:
         birthday = person['birthdays'][0]['date']
         if len(birthday) == 3:  # we skip incomplete birthdates
             contact.birthday = datetime.date(birthday['year'], birthday['month'], birthday['day'])
@@ -296,13 +313,9 @@ def parse_contact(person, groupname_by_id):
             if field in name:
                 contact.all_names.append(name[field])
 
-    if contact.display_name is None:
+    if contact.display_name is None and contact.emails:
         # if there is no displayName use a email address
-        if contact.emails:
-            contact.display_name = contact.emails[0].value
-        else:
-            log.info('Skipping contact because of no name and no email: %s', person)
-            return None
+        contact.display_name = contact.emails[0].value
 
     for membership in person.get('memberships', []):
         if "contactGroupMembership" in membership:
@@ -312,12 +325,25 @@ def parse_contact(person, groupname_by_id):
     for phone in person.get('phoneNumbers', []):
         contact.phonenumbers.append(TypedValue(phone['value'], phone.get('type', '')))
 
+    for address in person.get('addresses', []):
+        if 'formattedValue' in address:
+            contact.addresses.append(TypedValue(address['formattedValue'], address.get('type', '')))
+
+    for item in person.get('imClients', []):
+        if 'username' in item:
+            contact.im.append(TypedValue(item['username'], item.get('protocol', '')))
+
     if 'organizations' in person.keys() and person['organizations']:
         for org in person['organizations']:
+            if not contact.display_name:
+                contact.display_name = org.get('name')
             contact.organizations.append(Storage(name=org.get('name'),
                                                  title=org.get('title'),
                                                  department=org.get('department')))
     log.debug('Parsed contact %s', contact)
+    if not contact.display_name:
+        log.info('Skipping contact because of no name/e-mail/organization: %s', person)
+        return None
     return contact
 
 
@@ -361,7 +387,7 @@ class GoogleContacts():
             x__xgafv=None,
             pageToken=None,
             sortOrder=None,
-            personFields='names,nicknames,emailAddresses,memberships,phoneNumbers,birthdays,imClients,organizations',
+            personFields='names,nicknames,emailAddresses,memberships,phoneNumbers,birthdays,imClients,organizations,addresses',
             requestSyncToken=None,
             syncToken=None,
             requestMask_includeField=None)
